@@ -47,8 +47,3 @@ class AnonymousDataClassWithFakesTestCase(unittest.TestCase):
         print()
         print(pdf)
         self.assertIsNotNone(pdf)
-
-    @unittest.skipIf(sys.platform.startswith("win") or sys.platform == "darwin", "tests are very slow")
-    def test_create_spark_dataframe_returns_not_none(self):
-        df = Autodata.create_spark_dataframe(DataClass, use_fake_data=True)
-        self.assertIsNotNone(df)
